@@ -56,7 +56,7 @@ class calculator:
         calories_label.set_alignment(xalign=1, yalign=0.5)
         calories_container.pack_start(calories_label)
         self.calories = hildon.Entry(gtk.HILDON_SIZE_AUTO)
-        self.calories.set_property('hildon-input-mode', gtk.HILDON_GTK_INPUT_MODE_NUMERIC)
+        self.calories.set_property('hildon-input-mode', gtk.HILDON_GTK_INPUT_MODE_NUMERIC | gtk.HILDON_GTK_INPUT_MODE_SPECIAL)
         calories_container.pack_start(self.calories)
         #self.calories.set_placeholder('Calories')
         container.pack_start(calories_container)
@@ -66,7 +66,7 @@ class calculator:
         fat_label.set_alignment(xalign=1, yalign=0.5)
         fat_container.pack_start(fat_label)
         self.fat = hildon.Entry(gtk.HILDON_SIZE_AUTO)
-        self.fat.set_property('hildon-input-mode', gtk.HILDON_GTK_INPUT_MODE_NUMERIC)
+        self.fat.set_property('hildon-input-mode', gtk.HILDON_GTK_INPUT_MODE_NUMERIC | gtk.HILDON_GTK_INPUT_MODE_SPECIAL)
         fat_container.pack_start(self.fat)
         #self.fat.set_placeholder('Fat')
         container.pack_start(fat_container)
@@ -76,7 +76,7 @@ class calculator:
         fiber_label.set_alignment(xalign=1, yalign=0.5)
         fiber_container.pack_start(fiber_label)
         self.fiber = hildon.Entry(gtk.HILDON_SIZE_AUTO)
-        self.fiber.set_property('hildon-input-mode', gtk.HILDON_GTK_INPUT_MODE_NUMERIC)
+        self.fiber.set_property('hildon-input-mode', gtk.HILDON_GTK_INPUT_MODE_NUMERIC | gtk.HILDON_GTK_INPUT_MODE_SPECIAL)
         fiber_container.pack_start(self.fiber)
         #self.fiber.set_placeholder('Fiber')
         container.pack_start(fiber_container)
@@ -97,7 +97,7 @@ class calculator:
         calories_label.set_alignment(xalign=1, yalign=0.5)
         calories_container.pack_start(calories_label)
         self.calories = hildon.Entry(gtk.HILDON_SIZE_AUTO)
-        self.calories.set_property('hildon-input-mode', gtk.HILDON_GTK_INPUT_MODE_NUMERIC)
+        self.calories.set_property('hildon-input-mode', gtk.HILDON_GTK_INPUT_MODE_NUMERIC | gtk.HILDON_GTK_INPUT_MODE_SPECIAL)
         calories_container.pack_start(self.calories)
         #self.calories.set_placeholder('Calories')
         container.pack_start(calories_container)
@@ -107,7 +107,7 @@ class calculator:
         fat_label.set_alignment(xalign=1, yalign=0.5)
         fat_container.pack_start(fat_label)
         self.fat = hildon.Entry(gtk.HILDON_SIZE_AUTO)
-        self.fat.set_property('hildon-input-mode', gtk.HILDON_GTK_INPUT_MODE_NUMERIC)
+        self.fat.set_property('hildon-input-mode', gtk.HILDON_GTK_INPUT_MODE_NUMERIC | gtk.HILDON_GTK_INPUT_MODE_SPECIAL)
         fat_container.pack_start(self.fat)
         #self.fat.set_placeholder('Fat')
         container.pack_start(fat_container)
